@@ -10,9 +10,10 @@ setup
 
 
 if [ "${OFFLINE}" != "yes" ]; then
-  pip install -U -r requirements_dev.txt
+  pip install -U --upgrade-strategy eager -e '.[dev]'
 fi
 
 cd ${PROJECT_ROOT}
 rm -rf *.egg-info build dist
 python setup.py sdist bdist_wheel
+
